"use strict";

// Everything beneath here could be in a Userscript (for Greasemonkey, TamperMonkey, etc.)
// ...if concatenate to end of session.js

const URL = location.href;
const match = URL.match(/[0-9]{2}-[0-9]{2}(?=\/)/);
const SESSION = match && match[0];

// Navigate sessions with ctrl-left and ctrl-right

if (SESSION) {
  const y1 = Number(SESSION.slice(0, 2));
  const prev = sessionString(y1 - 1);
  const next = sessionString(y1 + 1);

  for (const [key, newSession] of [['Right', next], ['Left', prev], ['Up', thisSession]]) {
    document.addEventListener('keyup', e => {
      if ((e.code == ('Arrow' + key)) && (e.ctrlKey || e.metaKey)) {
        location.href = URL.replace(SESSION, newSession);
      }
    });
  }
}


// Add hyperlinks to course codes and unformatted URLs.

function addLinks(node, regex, urlFn) {
  for (let curNode of [... node.childNodes]) {
    if (curNode.nodeType == Node.ELEMENT_NODE) {
      const skip = ['a', 'style', 'script', 'h1'];
      const tag = curNode.tagName.toLowerCase();
      if (skip.indexOf(tag) == -1) {
        addLinks(curNode, regex, urlFn);
      }
    } else if (curNode.nodeType == Node.TEXT_NODE) {
      let match;
      while (match = curNode.textContent.match(regex)) { // not ==
        if (match.index == undefined) {
          console.log('Problem with matching. Maybe used g in regex?');
          return;
        }
        const nextNode = curNode.splitText(match.index + match[0].length);
        curNode.textContent = curNode.textContent.slice(0, match.index);
        let linkNode = document.createElement('a');
        linkNode.href = urlFn(match[0]);
        linkNode.textContent = match[0];
        node.insertBefore(linkNode, nextNode);
        curNode = nextNode;
      }
    }
  }
}

// There's a trade-off with last character in this regex. Will miss some URLs,
// but will spuriously pull in punctuation and formatting less often.
if (SESSION) {
  const urlRegex = /(https?:\/\/|www\.)[^ \n]+[a-zA-Z0-9/]/;
  addLinks(document.body, urlRegex, x => (x.slice(0, 4) == 'http') ? x : 'http://' + x);
  function courseLink(code) {
    return 'http://www.drps.ed.ac.uk/' + SESSION + '/dpt/cx' + code.toLowerCase() + '.htm';
  }
  const courseRegex = /([a-zA-Z]{4}[01][0-9]{4})(?=([^0-9]|$))/;
  addLinks(document.body, courseRegex, courseLink);
}
